CREATE TABLE ASSET_TYPE (
  ID_ASSET_TYPE NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT ASSET_TYPE_PK PRIMARY KEY (ID_ASSET_TYPE)
);

CREATE SEQUENCE ASSET_TYPE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE ASSET_CATEGORY (
  ID_ASSET_CATEGORY NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT ASSET_CATEGORY_PK PRIMARY KEY (ID_ASSET_CATEGORY)
);

CREATE SEQUENCE ASSET_CATEGORY_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE ASSET (
  ID_ASSET NUMBER NOT NULL,
  ID_TYPE NUMBER,
  ID_CATEGORY NUMBER,
  NAME VARCHAR2(100 CHAR),
  DESCRIPTION VARCHAR2(250 CHAR),
  SERIAL_NUMBER VARCHAR2(100 CHAR),
  REGISTRATION_NUMBER VARCHAR2(100 CHAR),
  INSURANCE_POLICY_NUMBER VARCHAR2(50 CHAR),
  INSURANCE_EXPIRY_DATE DATE,
  WARRANTY_EXPIRY_DATE DATE,
  MANAGER VARCHAR2(20 CHAR),
  PURCHASE_PRICE NUMBER,
  SERVICING_BUDGET NUMBER,
  NNLOCATION_ID NUMBER,
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT ASSET_PK PRIMARY KEY (ID_ASSET),
  CONSTRAINT ASSET_ASSET_TYPE_FK FOREIGN KEY (ID_TYPE) REFERENCES ASSET_TYPE(ID_ASSET_TYPE),
  CONSTRAINT ASSET_ASSET_CATEGORY_FK FOREIGN KEY (ID_CATEGORY) REFERENCES ASSET_CATEGORY(ID_ASSET_CATEGORY)
);

CREATE INDEX IX_ASSET_ID_TYPE ON ASSET (ID_TYPE);
CREATE INDEX IX_ASSET_ID_CATEGORY ON ASSET (ID_CATEGORY);

CREATE SEQUENCE ASSET_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_ASSET AS (
  SELECT A.ID_ASSET, A.ID_TYPE, A.ID_CATEGORY, A.NAME, A.DESCRIPTION, A.SERIAL_NUMBER, A.REGISTRATION_NUMBER, A.MANAGER, A.NNLOCATION_ID, A.ACTIVE,
  AT.DESCRIPTION AS TYPE_DESCRIPTION, AC.DESCRIPTION AS CATEGORY_DESCRIPTION, NU.USER_ AS NUSER_USER
  FROM ASSET A
  LEFT OUTER JOIN ASSET_TYPE AT ON AT.ID_ASSET_TYPE = A.ID_TYPE
  LEFT OUTER JOIN ASSET_CATEGORY AC ON AC.ID_ASSET_CATEGORY = A.ID_CATEGORY
  LEFT OUTER JOIN NUSER NU ON NU.NUSER = A.MANAGER
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1458, SYSDATE, '5.5', 1378, 'Assets')
;
